@@ -1,10 +1,10 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.083-3-gbc79817
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.084-7-gb371374
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 # vim: set ts=8 sw=4 tw=78 et :
-$Dist::Zilla::PluginBundle::Author::ETHER::VERSION = '0.084';
+$Dist::Zilla::PluginBundle::Author::ETHER::VERSION = '0.085';
 use Moose;
 with
     'Dist::Zilla::Role::PluginBundle::Easy',
@@ -250,10 +250,12 @@ sub configure
 
         # After Release
         [ 'CopyFilesFromRelease' => { filename => [ $self->copy_files_from_release ] } ],
-        [ 'Run::AfterRelease'   => 'remove old READMEs' => { ':version' => '0.024', eval => q!unlink 'README.md'! } ],
-        [ 'Git::Commit'         => 'release snapshot' => { ':version' => '2.020', add_files_in => ['.'], allow_dirty => [ uniq 'Changes', 'README.md', 'README.pod', $self->copy_files_from_release ], commit_msg => '%N-%v%t%n%n%c' } ],
+        ( -e 'README.md' ?
+            [ 'Run::AfterRelease' => 'remove old READMEs' => { ':version' => '0.024', eval => q!unlink 'README.md'! } ]
+            : ()),
+        [ 'Git::Commit'         => 'release snapshot' => { ':version' => '2.020', add_files_in => ['.'], allow_dirty => [ grep { -e } uniq 'Changes', 'README.md', 'README.pod', $self->copy_files_from_release ], commit_msg => '%N-%v%t%n%n%c' } ],
         [ 'Git::Tag'            => { tag_format => 'v%v%t', tag_message => 'v%v%t' } ],
-        $self->server eq 'github' ? [ 'GitHub::Update' => { metacpan => 1 } ] : (),
+        $self->server eq 'github' ? [ 'GitHub::Update' => { ':version' => '0.40', metacpan => 1 } ] : (),
         'Git::Push',
     );
 
@@ -261,7 +263,7 @@ sub configure
     # hopefully the file is available at this location soonish after release!
     my ($username, $password) = $self->_pause_config;
     push @plugins,
-        [ 'Run::AfterRelease' => 'install release' => { ':version' => '0.029', fatal_errors => 0, run => 'cpanm http://' . $username . ':' . $password . '@pause.perl.org/pub/PAUSE/authors/id/' . substr($username, 0, 1).'/'.substr($username,0,2).'/'.$username.'/%a' } ] if $username and $password;
+        [ 'Run::AfterRelease' => 'install release' => { ':version' => '0.031', fatal_errors => 0, run => 'cpanm http://' . $username . ':' . $password . '@pause.perl.org/pub/PAUSE/authors/id/' . substr($username, 0, 1).'/'.substr($username,0,2).'/'.$username.'/%a' } ] if $username and $password;
 
     if ($self->airplane)
     {
@@ -283,6 +285,7 @@ sub configure
     }
 
     push @plugins, (
+        [ 'Run::AfterRelease'   => 'release complete' => { ':version' => '0.024', eval => [ qq{print "release complete!\n"} ] } ],
         # listed late, to allow all other plugins which do BeforeRelease checks to run first.
         'ConfirmRelease',
     );
@@ -353,7 +356,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.084
+version 0.085
 
 =head1 SYNOPSIS
 
@@ -607,15 +610,19 @@ following F<dist.ini> (following the preamble):
     tag_message = v%v%t
 
     [GitHub::Update]    ; (if server = 'github' or omitted)
+    :version = 0.40
     metacpan = 1
 
     [Git::Push]
 
     [Run::AfterRelease / install release]
-    :version = 0.029
+    :version = 0.031
     fatal_errors = 0
     run = cpanm http://URMOM:mysekritpassword@pause.perl.org/pub/PAUSE/authors/id/U/UR/URMOM/%a
 
+    [Run::AfterRelease / release complete]
+    :version = 0.024
+    eval = print "release complete!\n"
 
     ; listed late, to allow all other plugins which do BeforeRelease checks to run first.
     [ConfirmRelease]
